package peermgr

import (
	"fmt"
	"testing"

	peer2 "github.com/libp2p/go-libp2p-core/peer"
	"github.com/meshplus/bitxhub-kit/crypto"
	"github.com/meshplus/bitxhub-kit/crypto/asym"
	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
)

func TestLoadPeers(t *testing.T) {
	var (
		port = 4567
	)
	var peers []string
	var nodeKeys []crypto.PrivateKey
	var ids []string

	key, err := asym.GenerateKeyPair(crypto.ECDSA_P256)
	require.Nil(t, err)
	nodeKeys = append(nodeKeys, key)

	libp2pKey, err := convertToLibp2pPrivKey(key)
	require.Nil(t, err)

	idTmp, err := peer2.IDFromPrivateKey(libp2pKey)
	require.Nil(t, err)
	ids = append(ids, idTmp.String())

	peer := fmt.Sprintf("/ip4/127.0.0.1/tcp/%d/p2p/%s", port, idTmp)
	peers = append(peers, peer, fmt.Sprintf("/ip4/104.236.76.40/tcp/4001/ipfs/QmSoLV4Bbm51jM9C4gDYZQ9Cy3U6aXMJDAbzgu2fzawe34"))

	l, ps, err := loadPeers(peers, libp2pKey)
	t.Log(l)
	t.Log(ps)
	assert.Nil(t, err)
}
